﻿local addonName, FLC = ...; -- gets addon-local variables

local L = FLC.LOCALIZATION;

----------------------------------------------------------------------------------------------------
-- Slash commands

SlashCmdList['FAIRLANGUAGE_SLASHCMD'] = function( msg, ... )
    local command, args = msg:match("^(%S*)%s*(.-)$");
    
    command = strlower(command);
    args = strtrim(args);

    ---------------------   
    -- Main Commands
    if ( command == "on" ) then 
        -- activates text modification with languge tag
        FLC.on = true;
        FLC.printInfo(addonName .. L.chat.MSG_FLC_ACTIVATED..".");
        -- rebuild LanguageMenu with own languages
        FLC.refreshMenuLanguages();
       
    elseif ( command == "off" ) then 
        -- disables text modification
        FLC.on = false;
        FLC.printInfo(addonName .. L.chat.MSG_FLC_DEACTIVATED .. ".");
        
        -- reset LanguageMenu to default
        UIMenu_Initialize(LanguageMenu);
        LanguageMenu_LoadLanguages(LanguageMenu);
        
    elseif ( command == "toggle" or command == "t" ) then 
        FLC.toggle();
                
    elseif ( command == "?" or command == "whatlang" or command == "whatlanguage") then 
        -- sets the given language as active
        FLC.printActiveLanguage();
        
    elseif ( command == "setlang" or command == "setlanguage" ) then 
        -- sets the given language as active
        if( strlen(args) > 0 and strlen(args) <= FLC.LANGUAGE_MAX_SIZE ) then
            FLC.setActiveLanguage(args);
            FLC.printActiveLanguage();
        else
            FLC.printInfo(L.chat.MSG_ERROR_LANGUAGE_TOO_LONG .. " (<= "..FLC.LANGUAGE_MAX_SIZE.."): " .. args); -- Set
        end 
                
    elseif ( command == "learn" or command == "l" ) then
        if ( #(FLC.menuLanguages) < FLC.LANGUAGEMENU_MAX_SIZE ) then
            if( strlen(args) > 0 and strlen(args) <= FLC.LANGUAGE_MAX_SIZE ) then
                if(FLC.addMenuLanguage(args)) then
                    FLC.refreshMenuLanguages();
                    FLC.printInfo(L.chat.MSG_LEARNED .. ": " .. args);
                else
                    FLC.printInfo(L.chat.MSG_ALREADYLEARNED .. ": " .. args);
                end
            else
                FLC.printInfo(L.chat.MSG_ERROR_LANGUAGE_TOO_LONG .. " (<= "..FLC.LANGUAGE_MAX_SIZE..")."); -- learn
            end
        else
            FLC.printInfo(L.chat.MSG_ERROR_LANGUAGE_TOO_MANY .. " (< "..FLC.LANGUAGEMENU_MAX_SIZE.."): " .. args);
        end
    
    elseif ( command == "unlearn" or command == "u" ) then
        FLC.removeMenuLanguage(args);
        FLC.correctSpeech(args);
        FLC.refreshMenuLanguages();
        
        FLC.printInfo(L.chat.MSG_FORGOTTEN .. ": " .. args);
        
    elseif ( command == "unlearnall" ) then
        FLC.clearMenuLanguages();
        FLC.refreshMenuLanguages();
                
        FLC.printInfo(L.chat.MSG_FORGOTTENALL); 
                
    elseif ( command == "cycle" or command == "c" ) then
        FLC.cycleMenuLanguages();
        
    ---------------------        
    -- Pro commands
    elseif ( command == "cyclelanguage" or command == "cyclelang" ) then    
        -- cycles through the given languages
        local tbl = { strsplit(",", args) };
        local foundActive = false;
        for i, v in pairs(tbl) do
            tbl[i] = strtrim(v);
            if( strlen(v) == 0 or strlen(v) > FLC.LANGUAGE_MAX_SIZE ) then
                FLC.printInfo(L.chat.MSG_ERROR_LANGUAGE_TOO_LONG .. " (<= "..FLC.LANGUAGE_MAX_SIZE.."): " ..v); -- cycle
                return;
            end 
        end
        for i, v in pairs(tbl) do
            -- spoken native language found, use next
            if ( tbl[i] == FLC.commonLanguage and not FLC.speakingOwnLanguage() ) then
                local nextIndex = mod(i,#tbl) + 1;
                FLC.setActiveLanguage(tbl[nextIndex]);
                FLC.printActiveLanguage();
                foundActive = true;
                break;
            -- spoken own language found, use next
            elseif ( tbl[i] == FLC.activeLanguage and FLC.speakingOwnLanguage() ) then
                local nextIndex = mod(i,#tbl) + 1;
                FLC.setActiveLanguage(tbl[nextIndex]);
                FLC.printActiveLanguage();
                foundActive = true;
                break;
            end
        end
        
        -- if no next found, use the first one
        if (foundActive == false) then
            FLC.setActiveLanguage(tbl[1]);
            FLC.printActiveLanguage();
        end
    
    elseif ( command == "ml" or command == "mlang" or command == "mlanguage" ) then
        -- temporary langueage change for macro etc.
        if( strlen(args) > 0 and strlen(args) <= FLC.LANGUAGE_MAX_SIZE ) then
            FLC.tempLanguage = args;   
        else
            FLC.printInfo(L.chat.MSG_ERROR_LANGUAGE_TOO_LONG .. " (<= "..FLC.LANGUAGE_MAX_SIZE.."): " .. args); -- macro
        end 
        
    elseif ( command == "nativelang" or command == "nativelanguage") then 
        -- using the native language
        FLC.setActiveLanguage( FLC.nativeLanguage );
        FLC.printActiveLanguage();
        
    elseif ( command == "commonlang" or command == "commonlanguage" ) then 
        -- uses the common language
        FLC.setActiveLanguage( FLC.commonLanguage );
        FLC.printActiveLanguage();
    
    elseif ( command == "prevlang" or command == "prevlanguage" ) then 
        -- sets the previous language
        local newLast = FLC.activeLanguage;
        FLC.setActiveLanguage( FLC.prevLanguage );
        FLC.printActiveLanguage();
        FLC.isOwn = FLC.speakingOwnLanguage();
        
        FLC.prevLanguage = newLast;
        
    elseif ( command == "addchan" ) then 
        -- resets the active language to your old
        if ( FLC.usedChannels[args] ~= nil ) then
            FLC.usedChannels[args] = true;            
        end
        FLC.printInfo(addonName .. ": " .. args .. " [true]");
        
    elseif ( command == "removechan" ) then 
        -- resets the active language to your old
        if ( FLC.usedChannels[args] ~= nil ) then
            FLC.usedChannels[args] = false;
        end
        FLC.printInfo(addonName .. ": " .. args .. " [false]");
    
    elseif ( command == "channels" ) then
        FLC.printInfo("FairLanguage - " .. L.helppro.MSG_POSSIBLECHAN.. ":");
        for i,v in pairs(FLC.usedChannels) do
            FLC.printInfo(FLC.colors.chatcommand.."       " .. i .. " = " .. tostring(v) .. "|r");
        end
        
        
    ---------------------        
    -- help commands
    elseif ( command == "help" ) then
        -- prints possible commands
        local col1 = FLC.colors.chatcommand;
        
        FLC.printInfo(addonName .. " ".. L.help.MSG_CMD .. ":");
        FLC.printInfo(col1.."    /fairlanguage, /fairlang, /flc  |r");
        FLC.printInfo(col1.."    /flc help  |r" .. L.help.MSG_HELP .. "");
        FLC.printInfo(col1.."    /flc on  |r" .. L.help.MSG_ON .. "");
        FLC.printInfo(col1.."    /flc off  |r" .. L.help.MSG_OFF .. "");
        FLC.printInfo(col1.."    /flc ?  |r" .. L.help.MSG_WHATLANG .. "");
        FLC.printInfo(col1.."    /flc toggle  |r" .. L.help.MSG_TOGGLEINPUT .. "");
        FLC.printInfo(col1.."    /flc cycle  |r" .. L.help.MSG_CYCLEMENULANG .. "");
        
        FLC.printInfo(col1.."    /flc setlanguage language  |r" .. L.help.MSG_SETLANG .. "");
        FLC.printInfo(col1.."    /flc learn language  |r" .. L.help.MSG_LEARN .. "");
        FLC.printInfo(col1.."    /flc unlearn language  |r" .. L.help.MSG_UNLEARN .. "");
        FLC.printInfo(col1.."    /flc unlearnall  |r" .. L.help.MSG_UNLEARALL .. "");
        
    elseif ( command == "helppro" ) then    
        FLC.printInfo(addonName .. " ".. L.help.MSG_CMD .. " pro:");
        local col1 = FLC.colors.chatcommand;
        
        FLC.printInfo(col1.."    /flc cyclelanguage lang1, lang2, ...  |r" .. L.helppro.MSG_CYCLELANG .. "");
        FLC.printInfo(col1.."    /flc mlanguage language |r" .. L.helppro.MSG_MACROLANG .. "");
        FLC.printInfo(col1.."    /flc prevlanguage  |r" .. L.helppro.MSG_prevLang .. "");
        FLC.printInfo(col1.."    /flc nativelanguage  |r" .. L.helppro.MSG_NATIVELANG .. "");
        FLC.printInfo(col1.."    /flc commonlanguage  |r" .. L.helppro.MSG_COMMONLANG .. "");
        FLC.printInfo(col1.."    /flc addchan channel  |r" .. L.helppro.MSG_ADDCHAN .. "");
        FLC.printInfo(col1.."    /flc removechan channel  |r" .. L.helppro.MSG_REMOVECHAN .. "");
        FLC.printInfo(col1.."    /flc channels  |r" .. L.helppro.MSG_SHOWCHANNELS .. "");
        
    else
        FLC.printInfo(L.chat.MSG_COMMANDERROR .. FLC.colors.chatcommand .. " /flc help|r");
    end
end
SLASH_FAIRLANGUAGE_SLASHCMD1 = '/fairlanguage';
SLASH_FAIRLANGUAGE_SLASHCMD2 = '/fairlang';
SLASH_FAIRLANGUAGE_SLASHCMD3 = '/flc'; -- Fair Language Core



----------------------------------------------------------------------------------------------------
-- Slash command functions

function FLC.cycleMenuLanguages()
    local lang = FLC.getSpokenLanguage();
    local foundNext = false;
    
    for id = 1, LanguageMenu.numButtons do
        local button = _G[LanguageMenu:GetName().."Button"..id];
        if ( button:GetText() == lang ) then
            local nextID = ((id) % (LanguageMenu.numButtons)) + 1;
            local nextButton = _G[LanguageMenu:GetName().."Button"..nextID];
            FLC.setActiveLanguage(nextButton:GetText());
            FLC.printActiveLanguage();
            foundNext = true;
            break;
        end
    end
    
    if ( foundNext == false ) then
        local button = _G[LanguageMenu:GetName().."Button1"];
        FLC.setActiveLanguage(button:GetText());
        FLC.printActiveLanguage();
    end
end

function FLC.toggle()
    -- toggles input box between common and native/own
    local isOwn = FLC.speakingOwnLanguage();
    FLC.setBoxLanguage( not isOwn );
    FLC.isOwn = not isOwn;
    FLC.printActiveLanguage();
end

function FLC.correctSpeech( language )
    if ( strlower(FLC.prevLanguage) == strlower(language) ) then
        FLC.prevLanguage = FLC.nativeLanguage;
    end
    if ( strlower(FLC.activeLanguage) == strlower(language) ) then
        FLC.activeLanguage = FLC.nativeLanguage;
        FLC.setActiveLanguage(FLC.commonLanguage);
        FLC.printActiveLanguage();
    end    
end