﻿local addonName, FLC = ...; -- gets addon-local variables

local L = FLC.LOCALIZATION;

----------------------------------------------------------------------------------------------------
-- FairLanguage Core System

function FairLanguage_OnLoad ( self )
    self:RegisterEvent( "ADDON_LOADED" );
    self:RegisterEvent( "PLAYER_LOGIN" );
    -- self:RegisterEvent( "VARIABLES_LOADED" );
    self:RegisterEvent( "PLAYER_ENTERING_WORLD" );
    self:RegisterEvent( "PLAYER_LEAVING_WORLD" );
    self:RegisterEvent( "PLAYER_LOGOUT" );
    
    self:RegisterEvent( "LANGUAGE_LIST_CHANGED");
end

function FairLanguage_OnEvent( self, event, ...)
    local args = {...};
    
    -- While playing
    if ( event == "LANGUAGE_LIST_CHANGED" ) then
        FLC.updatedLanguages();
        
    -- Loading the Game / Zoning in
    elseif (event == "ADDON_LOADED" and  ... == "FairLanguage") then
        -- Addon and saved variables loaded
        FLC.loadVariables();
        
    elseif ( event == "PLAYER_LOGIN" ) then
        -- most game variables are accessible
        FLC.start(self);
        
    elseif ( event == "PLAYER_ENTERING_WORLD" ) then
        -- after PLAYER_LOGIN or after zoning
        FLC.reload();
        
    -- Closing the Game / Zoning out
    elseif ( event == "PLAYER_LEAVING_WORLD" ) then
        -- before PLAYER_LOGOUT
        FLC.leaveWorld();
        
    elseif ( event == "PLAYER_LOGOUT" ) then
        -- no access to player functionalities anymore
        -- prepare variables for saving
        FLC.saveVariables();
        
    elseif ( event == "NEUTRAL_FACTION_SELECT_RESULT" ) then
        -- React on Faction change        
        FLC.initDefaultLanguages();
        FairLanguageCoreFrame:UnregisterEvent( "NEUTRAL_FACTION_SELECT_RESULT" );
        
    end
end

function FLC.start( self )
    FLC.initDefaultLanguages();
    
    -- Pandaren (Neutral) Fix XXX
    if (factionGroup == "Neutral") then
        FairLanguageCoreFrame:RegisterEvent( "NEUTRAL_FACTION_SELECT_RESULT" );
    end
    
    -- sets active and last to common at first init
    if ( FLC.activeLanguage == "" ) then
        FLC.activeLanguage = FLC.nativeLanguage;
    end
    if ( FLC.prevLanguage == "" ) then
        FLC.prevLanguage   = FLC.nativeLanguage;
    end
    FLC.setBoxLanguage(FLC.isOwn);
    
    FLC.printInfo(addonName .. " " .. L.chat.MSG_LOADED .. " ("..FLC.colors.chatcommand.."/flc|r). " .. L.chat.MSG_LANGACTIVE .. ": " .. FLC.activeLanguage);
    FLC.printActiveLanguage();
end

--/ Reloads the language after zoning
function FLC.reload()
    local isOwn = FLC.isOwn;
    FLC.setBoxLanguage(isOwn);
    
    FLC.setActiveLanguage (FLC.getSpokenLanguage() );
    FLC.isOwn = isOwn;
    FLC.setBoxLanguage(isOwn);
    
    FLC.refreshMenuLanguages();
end

--/ last chance to access player specific functions, called before zoning
function FLC.leaveWorld()    
    -- if ( GetNumLanguages() > 1 ) then
    if ( FLC.numLanguages > 1 ) then
        if ( DEFAULT_CHAT_FRAME.editBox.language ~= FLC.commonLanguage) then
            FLC.isOwn = true;
        else
            FLC.isOwn = false;
        end
    end
end

--/ Saves specific information
function FLC.saveVariables()
    FairLanguageCore = {};
    
    FairLanguageCore["options"] = {};
    FairLanguageCore["options"]["version"] = GetAddOnMetadata(addonName,"Version");
    
    FairLanguageCore["config"] = {};
    FairLanguageCore["config"]["isOn"]         = FLC.on;
    FairLanguageCore["config"]["usedChannels"] = {};
    FairLanguageCore["config"]["usedChannels"] = FLC.usedChannels;
    
    FairLanguageCore["chatmenu"] = {};
    FairLanguageCore["chatmenu"]["menuLanguages"] = {};
    FairLanguageCore["chatmenu"]["menuLanguages"] = FLC.menuLanguages;    
    
    FairLanguageCore["language"] = {};
    FairLanguageCore["language"]["isOwn"]      = FLC.isOwn;
    FairLanguageCore["language"]["activeLang"] = FLC.activeLanguage;
    FairLanguageCore["language"]["prevLang"]   = FLC.prevLanguage;
end

--/ Loads specific information
function FLC.loadVariables() 
    if ( FairLanguageCore ~= nil ) then     
        -- next initialisation, loads saved variables into local scope
        FLC.on           = FairLanguageCore["config"]["isOn"];
        FLC.usedChannels = FairLanguageCore["config"]["usedChannels"];
        
        FLC.isOwn          = FairLanguageCore["language"]["isOwn"];
        FLC.activeLanguage = FairLanguageCore["language"]["activeLang"];
        FLC.prevLanguage   = FairLanguageCore["language"]["prevLang"]
        
        FLC.menuLanguages = FairLanguageCore["chatmenu"]["menuLanguages"];
    else
        -- first initialisation, use default values
    end
    
    if(FLC.menuLanguages == nil) then
        FLC.menuLanguages = {};
    end
    FairLanguageCore = {};
end

--/ Handles updates of the language List
function FLC.updatedLanguages()
    -- Update language counts?
    FLC.numLanguages = GetNumLanguages();
    
    -- Update Menu
    FLC.refreshMenuLanguages();
end



----------------------------------------------------------------------------------------------------
-- FairLanguage Core Language Management

function FLC.initDefaultLanguages()
    local factionGroup, _ = UnitFactionGroup("player") -- 1 Alliance/Horde
    local _, fileName = UnitRace("player") -- 2

    -- sets common and native language
    FLC.commonLanguage = GetDefaultLanguage("player");    
    
    FLC.numLanguages = GetNumLanguages();
    
    for i = 1, GetNumLanguages() do
        local lang, id = GetLanguageByIndex(i);
        if ( id == FLC.raceLangs[factionGroup][fileName] ) then
            FLC.nativeLanguage = lang;
        end
    end
    if FLC.nativeLanguage == "" then
        FLC.nativeLanguage = FLC.commonLanguage;
    end
end

function FLC.setActiveLanguage( language ) 
    if ( language ~= FLC.commonLanguage ) then
        -- using native/own language
        FLC.isOwn = true;
        if ( FLC.activeLanguage ~= language) then
            FLC.prevLanguage = FLC.activeLanguage;
        end
        FLC.activeLanguage = language; 
    else 
        -- using common language
        FLC.isOwn = false;
    end
    FLC.setBoxLanguage(FLC.isOwn);
    --FLC.printActiveLanguage();
end


--/ Sets the language of the typing box
--/ @param isNativeLang 
--/     true if your own or native language shall be used
--/     false if your common language shall be used
function FLC.setBoxLanguage(isNativeLang)
    if (isNativeLang == true) then
        DEFAULT_CHAT_FRAME.editBox.language = FLC.nativeLanguage;
    else
        DEFAULT_CHAT_FRAME.editBox.language = FLC.commonLanguage;
    end
end

function FLC.isAllowedChannel( chatType ) 
    if ( FLC.usedChannels[chatType] ~= nil ) then
        return FLC.usedChannels[chatType];
    else
        return false;
    end
end

--/ Checks wether which type of language is actually spoken
--/ @returns 
--/      true if speaking native or own language
--/      false if speaking common language
function FLC.speakingOwnLanguage()    
    if ( GetNumLanguages() > 1 and FLC.commonLanguage ~= FLC.nativeLanguage) then
        -- special case for macro lang
        if (FLC.tempLanguage ~= nil and FLC.tempLanguage ~= "") then
            return true;
        -- characters with native language, priorizing editBox state
        elseif ( DEFAULT_CHAT_FRAME.editBox.language ~= FLC.commonLanguage ) then
            -- using own
            return true;
        elseif ( DEFAULT_CHAT_FRAME.editBox.language == FLC.commonLanguage ) then
            -- using common
            return false;
        else
            -- using common (dead code)
            return FLC.isOwn;
        end
    else
        -- characters without native language
        if (FLC.isOwn == true) then 
            -- using own language
            return true;
        else
            -- using common language
            return false;
        end
    end
end

function FLC.getSpokenLanguage()
    if ( FLC.speakingOwnLanguage() ) then
        return FLC.activeLanguage;
    else
        return FLC.commonLanguage;
    end
end

function FLC.printActiveLanguage()
    FLC.printInfo(L.chat.MSG_CHANGEINPUT .. ": " .. FLC.getSpokenLanguage());
end