﻿local addonName, FLC = ...; -- gets addon-local variables

----------------------------------------------------------------------------------------------------
-- Modifies LanguageMenu

--/ Sets the language by index from the LanguageMenu of the chat
function FLC.setMenuLanguage(self)     
    FLC.setActiveLanguage(self:GetText());
    FLC.printActiveLanguage();
    
	ChatMenu:Hide();
end

function FLC.addMenuLanguage(language)    
    for k,v in pairs (FLC.menuLanguages) do
        if ( strlower(language) == strlower(v)) then
            return false;
        end
    end    
    
    if not tContains(FLC.menuLanguages,language) then 
        table.insert(FLC.menuLanguages,language);
    end
    
    return true;
end

function FLC.removeMenuLanguage(language)    
    for k,v in pairs(FLC.menuLanguages) do
        if ( strlower(v) == strlower(language) ) then
            table.remove(FLC.menuLanguages,k);
            break;
        end
    end
    
    if ( FLC.activeLanguage == language ) then
        FLC.activeLanguage = FLC.nativeLanguage;
        FLC.setActiveLanguage(FLC.commonLanguage);
        FLC.printActiveLanguage();
    end
end

function FLC.clearMenuLanguages()
    -- check and remove any learned from previous or active language
    for k,v in pairs (FLC.menuLanguages) do
        FLC.correctSpeech(v);
    end

    FLC.menuLanguages = {};
end

function FLC.refreshMenuLanguages()
    -- reset LanguageMenu to default
    UIMenu_Initialize(LanguageMenu);
    LanguageMenu_LoadLanguages(LanguageMenu);
    
    -- Get blizzard language names
    local blizzLang = {};
    for i = 1, GetNumLanguages() do
        blizzLang[i] = GetLanguageByIndex(i);
    end
    
    -- Add own languages to menu
    for k,v in pairs (FLC.menuLanguages) do
        if (not tContains(blizzLang, v)) then
            UIMenu_AddButton(LanguageMenu, v, nil, FLC.setMenuLanguage);    
        end
    end
    
    UIMenu_AutoSize(LanguageMenu);
end



----------------------------------------------------------------------------------------------------
-- Hooking and modifying LanguageMenu_Click(self)

local hooked_LanguageMenu_Click = LanguageMenu_Click; -- original SendChatMessage (Hook)
function LanguageMenu_Click( self )
    
    if ( FLC.on == true and self:GetText() == FLC.commonLanguage ) then
        FLC.setActiveLanguage(FLC.commonLanguage);
        FLC.printActiveLanguage();
    elseif  ( FLC.on == true and self:GetText() == FLC.nativeLanguage) then
        FLC.setActiveLanguage( FLC.nativeLanguage);
        FLC.printActiveLanguage();
    -- elseif  ( FLC.on == true and self:GetText() == FLC.nativeLanguage) then
        -- FLC.setActiveLanguage(FLC.nativeLanguage);
        -- FLC.printActiveLanguage();
    elseif  ( FLC.on == true and self:GetText() ~= FLC.commonLanguage and self:GetText() ~= FLC.nativeLanguage) then
        FLC.setActiveLanguage(self:GetText());
        FLC.printActiveLanguage();
    else
        -- use the standard SendChatMessage
        -- hooked_LanguageMenu_Click(  self );
    end
    hooked_LanguageMenu_Click(  self );
    
end